@@ -7,8 +7,12 @@ uncamel_patterns = (
     re.compile('([a-z0-9])([A-Z])'),
     )
 
-invalid_pat = re.compile(r'[^a-z0-9_]')
-limit_pat = re.compile(r'_{2,}')
+invalid_att_pat = re.compile(r'[^_a-z0-9]')
+limit_underscore_pat = re.compile(r'_{2,}')
+
+invalid_model_pat = re.compile(r'[^-_a-zA-Z0-9]')
+to_space_pat = re.compile(r'[-_]')
+limit_space_pat = re.compile(r' {2,}')
 
 
 def uncamel(s):
@@ -35,10 +39,18 @@ def uncamel(s):
     return s.lower()
 
 
+def to_model(s):
+    s = invalid_model_pat.sub('', s)
+    s = to_space_pat.sub(' ', s)
+    s = limit_space_pat.sub(' ', s)
+    s = s.strip()
+    return ''.join(['%s%s' % (c[0].upper(), c[1:]) for c in s.split(' ')])
+
+
 def to_attname(s):
     s = uncamel(s)
-    s = invalid_pat.sub('_', s)
-    s = limit_pat.sub('_', s)
+    s = invalid_att_pat.sub('_', s)
+    s = limit_underscore_pat.sub('_', s)
     s = s.strip('_')
     if keyword.iskeyword(s):
         s = s + '_field'
